@@ -31,6 +31,16 @@ public class HTTPDate implements java.io.Serializable, Comparable<HTTPDate>{
 		date = d;
 	}
 
+	/**
+	 * コンストラクタ。指定時刻より構築します。
+	 * @param tm エポック
+	 * (1970 年 1 月 1 日 0 時 0 分 0 秒、グリニッジ標準時)
+	 * からの経過ミリ秒。
+	 */
+	public HTTPDate( long tm ) {
+		this( new Date( tm ) );
+	}
+
 	private SimpleDateFormat getFormat() {
 		SimpleDateFormat sdf = new SimpleDateFormat( "EEE, dd MMM yyyy HH:mm:ss z",
 			DateFormatSymbols.getInstance( Locale.ROOT ) );
