@@ -1380,6 +1380,7 @@ public abstract class Page implements Serializable {
 	 * @param c クッキー。
 	 */
 	public void addCookie( Cookie c ) {
+		if ( cookie == null )	cookie = new ArrayList<Cookie>();
 		cookie.add( c );
 	}
 
@@ -1387,6 +1388,7 @@ public abstract class Page implements Serializable {
 	 * フレームワークが使用します。
 	 */
 	public void setResponse( HttpServletResponse res ) {
+		if ( cookie == null )	return;
 		int	cnt = cookie.size();
 		for ( int i = 0; i < cnt; i++ ) {
 			res.addCookie( cookie.get( i ) );
