@@ -1020,7 +1020,7 @@ public enum WebChar {
 	 * &euro; euro sign
 	 */
 	_euro( '\u20ac', "&euro;" );
-	private static final long serialVersionUID = 1257072909000L;
+	private static final long serialVersionUID = 1260367499606L;
 	private static HashMap<Character, WebChar>	map = new HashMap<Character, WebChar>();
 	static {
 		WebChar[]	wc = values();
@@ -1049,7 +1049,19 @@ public enum WebChar {
 		return new String( new char[]{ ch } );
 	}
 
-	String getRef() {
+	/**
+	 * 文字化。１文字のcharとして扱う事ができます。
+	 * @return 文字。
+	 */
+	public char toChar() {
+		return ch;
+	}
+
+	/**
+	 * 文字参照の取得。&amp;nbsp; のような文字列を返します。
+	 * @return 文字参照。
+	 */
+	public String getReference() {
 		return ref;
 	}
 }
