@@ -7,7 +7,9 @@
 package paraselene.ajax.data;
 
 import paraselene.*;
+import paraselene.supervisor.*;
 import paraselene.tag.*;
+import paraselene.ui.*;
 import java.io.*;
 import java.util.*;
 
@@ -17,14 +19,22 @@ public class TagData implements Serializable {
 	public String	id = "";
 	public String	body = "";
 	public String[]	cmd = null;
+	public boolean	over_f = false;
 
 	TagData(){}
 	TagData( Tag tag ) {
 		this( tag, true );
 	}
+
 	TagData( Tag tag, boolean flag ) {
 		this.id = tag.getAttributeToString( "id" );
 		Page	page = tag.getAssignedPage();
+		if ( SandBox.isCurrentDaemon() ) {
+			PageHooker[]	hook = page.getPageHooker();
+			for ( int i = 0; i < hook.length; i++ ) {
+				hook[i].commitDaemon();
+			}
+		}
 		if ( flag ) {
 			int cnt = tag.getHTMLPartCount();
 			JsonWriter	w = new JsonWriter();
@@ -33,15 +43,29 @@ public class TagData implements Serializable {
 			}
 			body = w.toString();
 			cmd = new String[]{ page.getOnLoadScript() };
+			page.resetOnLoadScript();
+			tag.resetModify();
 		}
-		page.resetOnLoadScript();
 	}
 
-	public static TagData[] getTag( Page p ) {
+
+	public static TagData[] getTag( Page org, Page out ) {
 		ArrayList<TagData>	list = new ArrayList<TagData>();
-		Tag[]	tag = p.getModifiedTag();
-		for ( int i = 0; i < tag.length; i++ ) {
-			list.add( new TagData( tag[i] ) );
+		if ( org == out ) {
+			Tag[]	tag = out.getModifiedTag();
+			for ( int i = 0; i < tag.length; i++ ) {
+				list.add( new TagData( tag[i] ) );
+			}
+			int	cnt = list.size();
+			if ( cnt > 1 ) {
+				list.get( cnt - 1 ).cmd = list.get( 0 ).cmd;
+				list.get( 0 ).cmd = null;
+			}
+		}
+		else {
+			TagData	td = new TagData( out.getFirstTagByType( "body" ) );
+			td.id = org.getRootID();
+			list.add( td );
 		}
 		return list.toArray( new TagData[0] );
 	}
