@@ -34,5 +34,10 @@ public class NOP extends Feedback {
 		Option.trace( "new NopOutput <- %s", this );
 		return new NopOutput( nk, lp, this, r, sd );
 	}
+
+	CometCall makeCometCall( History h ) {
+		Option.trace( "new NopCometCall <- %s", this );
+		return new NopCometCall( h, this );
+	}
 }
 
