@@ -6,10 +6,12 @@
  */
 package paraselene.supervisor;
 
+import java.io.*;
+
 /**
  * サーバー情報。
  */
-public interface ServerInformation {
+public interface ServerInformation extends Serializable {
 	/**
 	 * ホスト名の取得。
 	 * @return ホスト名。
