@@ -407,8 +407,8 @@ public abstract class Supervisor extends HttpServlet {
 						fw = onIllegalRequest( IllegalRequest.SESSION_ERROR, req, path_data.from, path_data.to );
 						if ( fw != null ) {
 							session_f = fw.session_clear_f;
-							last_page = fact.getNullPage();
-							next_page = fw.getPage( null );
+							path_data.from = last_page = null;
+							path_data.to = next_page = fw.getPage( null );
 							if ( next_page == null ) {
 								fw.Action( this, res );
 								if ( session_f )	clear_session( session );
@@ -706,7 +706,7 @@ public abstract class Supervisor extends HttpServlet {
 			session = holder.getRequest().getSession( true );
 			session.setAttribute( SESSION_DATA, data );
 		}
-		if ( param.getMethod() == RequestParameter.Method.POST ) {
+		if ( !session_f && param.getMethod() == RequestParameter.Method.POST ) {
 			data.redirect( out_ret, fw, param ).Action( this, res );
 		}
 		else {
@@ -763,9 +763,11 @@ public abstract class Supervisor extends HttpServlet {
 				res.addHeader( "Cache-Control", "no-cache, no-store, must-revalidate" );
 			}
 			if ( fw != null ) {
-				int	ck_cnt = fw.out_cookie.size();
-				for ( int i = 0; i < ck_cnt; i++ ) {
-					res.addCookie( fw.out_cookie.get( i ) );
+				if ( fw.out_cookie != null ) {
+					int	ck_cnt = fw.out_cookie.size();
+					for ( int i = 0; i < ck_cnt; i++ ) {
+						res.addCookie( fw.out_cookie.get( i ) );
+					}
 				}
 			}
 			if ( gzip( param, holder.getRequest(), res, out_ret[1], data, mime ) ) {
