@@ -47,6 +47,12 @@ public class TransactionSequencer implements Serializable {
 	 * Paraselene拡張子。
 	 */
 	public static final String EXTENSION = "." + SELENE[3];
+	/**
+	 * Paraselene 仮URL。
+	 */
+	public static final String[] LINK_DEF = new String[] {
+		"PARASELENE(PAGE)", "PARASELENE(HTTP)", "PARASELENE(HTTPS)"
+	};
 	private volatile int seq = 0;
 	private HashMap<Integer,Boolean>	no_map = new HashMap<Integer,Boolean>();
 	private static final String[] HEAD = { "seleno", "lilith" };
