@@ -1408,5 +1408,47 @@ public class Tag extends HTMLPart {
 		return fw;
 	}
 
+	/**
+	 * クッキーへ値の保存。<br>
+	 * クッキーへ getValueString() したものを設定します。<br>
+	 * ただし、isEmptyValue() が true なら、クッキーへ保存しません。<br>
+	 * また、<ul>
+	 * <li>ページに属していないタグ
+	 * <li>name 属性を持たないタグ
+	 * </ul>もクッキーへ保存できません。
+	 * @param req リクエスト内容。
+	 * @param page 設定先インスタンス。
+	 * @param expiry クッキー存続時間(秒)。
+	 * @param ssl_f true:HTTPSの場合のみクッキーを返すようにする、
+	 * false:全てのプロトコルでクッキーを返すようにする。
+	 * @return page をそのまま返します。
+	 */
+	public Page exportToCookie( RequestParameter req, Page page, int expiry, boolean ssl_f ) {
+		if ( isEmptyValue() )	return page;
+		try {
+			page.addCookie( makeCookieValue( req, getValueString(), expiry, ssl_f ) );
+		}
+		catch( Exception e ){}
+		return page;
+	}
+
+	/**
+	 * クッキーへ値の保存。
+	 * このタグが所属するページにクッキーを設定します<br>
+	 * クッキーへ getValueString() したものを設定します。<br>
+	 * ただし、isEmptyValue() が true なら、クッキーへ保存しません。<br>
+	 * また、<ul>
+	 * <li>ページに属していないタグ
+	 * <li>name 属性を持たないタグ
+	 * </ul>もクッキーへ保存できません。
+	 * @param req リクエスト内容。
+	 * @param expiry クッキー存続時間(秒)。
+	 * @param ssl_f true:HTTPSの場合のみクッキーを返すようにする、
+	 * false:全てのプロトコルでクッキーを返すようにする。
+	 * @return このタグが所属するページ(クッキー設定先)を返します。
+	 */
+	public Page exportToCookie( RequestParameter req, int expiry, boolean ssl_f ) {
+		return exportToCookie( req, getAssignedPage(), expiry, ssl_f );
+	}
 }
 
