@@ -119,6 +119,29 @@ public class RadioGroup extends Control implements VirtualTag {
 		}
 	}
 
+	/**
+	 * 管理下のラジオボタンが全て無効であるか？
+	 * @return true:全て無効、false:全てまたは一部が有効。
+	 */
+	public boolean isDisabled() {
+		CheckBox[]	cb = getCheckBox();
+		for ( int i = 0; i < cb.length; i++ ) {
+			if ( cb[i].isDisabled() )	return false;
+		}
+		return true;
+	}
+
+	/**
+	 * 管理下のラジオボタンの無効状態を一括変更します。
+	 * @param flag true:無効、false:有効。
+	 */
+	public void setDisabled( boolean flag ) {
+		CheckBox[]	cb = getCheckBox();
+		for ( int i = 0; i < cb.length; i++ ) {
+			cb[i].setDisabled( flag );
+		}
+	}
+
 	/**
 	 * 管理下のラジオボタンのうち、選択されているものの設定値を返します。
 	 * @return 設定値。選択されていなければ null。
