@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009  Akira Terasaki
+ * Copyright (c) 2009, 2010  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -10,6 +10,7 @@ package paraselene.tag.form;
 import java.util.*;
 import paraselene.*;
 import paraselene.tag.*;
+import paraselene.supervisor.*;
 
 
 /**
@@ -122,6 +123,31 @@ public class Select extends Control {
 		return list.toArray( new String[0] );
 	}
 
+	/**
+	 * クッキーへ値の保存。
+	 * クッキーへ getValueStrings() したものを設定します。
+	 * ただし、getValueStrings() が 0個の配列を返したならば、クッキーへ保存しません。
+	 * また、<ul>
+	 * <li>ページに属していないタグ
+	 * <li>name 属性を持たないタグ
+	 * </ul>もクッキーへ保存できません。
+	 * @param req リクエスト内容。
+	 * @param fw 設定先インスタンス。
+	 * @param expiry クッキー存続時間(秒)。
+	 * @param ssl_f true:HTTPSの場合のみクッキーを返すようにする、
+	 * false:全てのプロトコルでクッキーを返すようにする。
+	 * @return fw をそのまま返します。
+	 */
+	public Forward exportToCookie( RequestParameter req, Forward fw, int expiry, boolean ssl_f ) {
+		String[]	val = getValueStrings();
+		if ( val.length == 0 )	return fw;
+		try {
+			fw.addCookie( makeCookieValue( req, val, expiry, ssl_f ) );
+		}
+		catch( Exception e ) {}
+		return fw;
+	}
+
 	/**
 	 * 選択値との比較。
 	 * 渡された文字列配列と、getValueStrings()結果が完全一致するか検査します。
@@ -191,6 +217,24 @@ public class Select extends Control {
 		}
 	}
 
+	/**
+	 * クッキーからの値を復元。
+	 * 自身のタグに対するクッキーから、以前の値を setValueString() します。
+	 * 複数の値が選択されていれば、それらを全て復元します。
+	 * ただし、isEmptyValue() が false なら処理しません。
+	 * @param req リクエスト内容。
+	 */
+	public void importFromCookie( RequestParameter req ) {
+		if ( !isEmptyValue() )	return;
+		try {
+			String[]	val = (String[])getCookieValue( req );
+			if ( val != null ) {
+				for ( int i = 0; i < val.length; i++ )	setValueString( val[i] );
+			}
+		}
+		catch( Exception e ){}
+	}
+
 	/**
 	 * 通番の選択アイテムを作成します。
 	 * タグの内部は全て消去され、新しく追加されます。<br>
